Learn R Programming

dbProject (version 0.1.0)

dbList,DBIConnection-method: List remote tables, temporary tables, and views

Description

Pretty prints tables, temporary tables, and views in the database.

Usage

# S4 method for DBIConnection
dbList(conn)

Arguments

conn

A DBIConnection object, as returned by DBI::dbConnect().

Details

Similar to DBI::dbListTables, but categorizes tables into three categories:

  • Tables

  • Temporary Tables (these will be removed when the connection is closed)

  • Views (these may be removed when the connection is closed)