Learn R Programming

dbProject (version 0.1.0)

dbverse-generics: Generic Function Definitions for dbverse

Description

This file contains all generic function definitions for the dbverse ecosystem. All generics are defined here once to avoid duplicate definition errors. Method implementations are defined in their respective files.

Arguments

Details

Centralizing generic definitions helps avoid the "no method found for function..." error that occurs when the same generic is defined in multiple files.