Learn R Programming

dbProject (version 0.1.0)

write_pin_conn.dbMatrix: Write a dbMatrix object to a pins board

Description

S3 method for writing dbMatrix objects to a pins board while maintaining connection state and metadata consistent with the connections package.

Usage

# S3 method for dbMatrix
write_pin_conn(x, board, name, ...)

Value

Invisibly returns the input object

Arguments

x

A dbMatrix object (dbSparseMatrix or dbDenseMatrix)

board

A pins pins::board_folder object

name

Name for the pin (required)

...

Additional arguments passed to pins::pin_write()