Pretty prints tables, temporary tables, and views in the database.
# S4 method for DBIConnection
dbList(conn)A DBIConnection object, as returned by DBI::dbConnect().
Similar to DBI::dbListTables, but categorizes tables into three categories:
Tables
Temporary Tables (these will be removed when the connection is closed)
Views (these may be removed when the connection is closed)