S3 method for writing dbMatrix objects to a pins board while maintaining connection state and metadata consistent with the connections package.
# S3 method for dbMatrix
write_pin_conn(x, board, name, ...)Invisibly returns the input object
A dbMatrix object (dbSparseMatrix or dbDenseMatrix)
A pins pins::board_folder object
Name for the pin (required)
Additional arguments passed to pins::pin_write()